#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define mod_name django-taggit
BuildArch:      noarch
Name:           python-%{mod_name}
Version:        5.0.1
Release:        1.3
Summary:        Django-taggit is a reusable Django application for simple tagging
License:        BSD-3-Clause-Clear
Group:          Development/Languages/Python
URL:            https://github.com/alex/django-taggit
Source:         https://pypi.python.org/packages/source/d/django-taggit/%{mod_name}-%{version}.tar.gz
BuildRequires:  %{python_module Django >= 4.2}
BuildRequires:  %{python_module djangorestframework}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 4.2
Recommends:     %{name}-lang = %{version}
%ifpython3 && ! 0%{?skip_python3}
%lang_package -n %{python3_prefix}-django-taggit
%endif
%python_subpackages

%description
Django-taggit is a reusable Django application for simple tagging.

%prep
%setup -q -n django-taggit-%{version}

%build
%python_build

%install
%python_install
%find_lang django
%python_expand grep -F %{$python_sitelib} django.lang > django_%{$python_bin_suffix}.lang
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand $python -m django test -v 2 --settings=tests.settings

%files %{python_files}
%license LICENSE
%doc AUTHORS CHANGELOG.rst README.rst
%{python_sitelib}/taggit/
%{python_sitelib}/django[-_]taggit*/
%exclude %{python_sitelib}/taggit/locale

%ifpython3 && ! 0%{?skip_python3}
%files -n %{python3_prefix}-django-taggit-lang -f django_%{python3_bin_suffix}.lang
%{python3_sitelib}/taggit/locale
%endif

%changelog
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0.1:
  * Fix the package metadata to properly reflect the right Django
    and Python version requirements
  * **Backwards icompatible:** Rename the (``content_type``,
    ``object_id``) index on ``TaggedItem``.
  * Remove support for Django 3.2.
  * Remove usage of deprecated APIs for Django 4.2
  * Remove support for Python 3.7 (no code changes involved)
  * Fix ``tag_kwargs`` and ``TAGGIT_CASE_INSENSITIVE=True``
    discrepency.
* Fri May  5 2023 Markéta Machová <mmachova@suse.com>
- update to 4.0.0
  * Remove Python 3.6 support (no code changes occurred, but we no longer test this release).
  * Remove Django 4.0 support (no code changes occurred, but we no longer test this release).
  * Add Django 4.2 support.
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 3.1.0:
  * Add Python 3.11 support
  * Add Django 4.1 support
  * Fixed an issue where object caches would not be properly cleared after
    updating tags, leading
  to stale reads in cases where ``prefetch_related`` is used.
  * Change ``TagListSerializerField`` to be a subclass of ``ListField``.
    This should improve support for API document generation. This change
    should not affect API behavior, but might affect metaprogramming code,
    so please procede carefully during this update.
* Sat Oct 15 2022 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v3.0.0
  * Backwards incompatible: Tag slugification used to silently strip
    non-ASCII characters from the tag name to make the slug. This
    leads to a lot of confusion for anyone using languages with
    non-latin alphabets, as well as weird performance issues.
  * Tag slugification will now, by default, maintain unicode characters
    as-is during slugification. This will lead to less surprises, but
    might cause issues for you if you are expecting all of your tag
    slugs to fit within a regex like [a-zA-Z0-9] (for example in URL
    routing configurations).
  * Generally speaking, this should not require action on your part
    as a library user, as existing tag slugs are persisted in the
    database, and only new tags will receive the enhanced
    unicode-compatible slug.
  * If you wish to maintain the old stripping behavior, set the setting
    TAGGIT_STRIP_UNICODE_WHEN_SLUGIFYING to True.
  * As a reminder, custom tag models can easily customize slugification
    behavior by overriding the slugify method to your business needs.
  * Drop Django 2.2 support.
* Wed Apr 13 2022 Misha Komarovskiy <zombah@gmail.com>
- Update to 2.1.0
  * Add Python 3.10 support.
  * Add Django 4.0 support.
  * Drop Django 3.1 support.
* Tue Dec  7 2021 Misha Komarovskiy <zombah@gmail.com>
- Update to 2.0.0
  * Backwards incompatible: TaggableManager.set now takes a list of
    tags (instead of varargs) so that its API matches Django's
    RelatedManager.set
  * Fix issue where TagField would incorrectly report that a field
    has changed on empty values.
  * Update Russian translation.
  * Add Persian translation
  * Fix issue for many languages where content types were not
    being properly translated.
  * Provide translators additional context regarding strings in TagBase model.
* Wed Jul  7 2021 Daniel Molkentin <daniel.molkentin@suse.com>
- Update to 1.5.1
  * Fix compiled Ukranian translation (which would cause a failure on load for this locale).
  * Update compiled Danish translation.
- Update to 1.5.0
  * Vendor in the django-taggit-serializer project (under taggit.serializers).
  * Add Arabic translation.
  * Add Ukranian translation.
* Mon May 10 2021 Daniel Molkentin <daniel.molkentin@suse.com>
- Update to version 1.4.0
  * Bump the taggit version number to 1.4.0
* Mon Aug 24 2020 Daniel Molkentin <daniel.molkentin@suse.com>
- Update to version 1.3.0
  * Model and field verbose_name and verbose_name_plural attributes are now
    lowercase. This simplifies using the name in the middle of a sentence.
    When used as a header, title, or at the beginning of a sentence, a text
    transformed can be used to adjust the case.
  * Fix prefetch_related when using UUIDTaggedItem.
  * Allow for passing in extra constructor parameters when using
    TaggableManager.add. This is especially useful when using custom tag models.
* Sat Jan 18 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to version 1.2.0
  * **Removed** support for end-of-life Django 2.0 and 2.1.
  * Added support for Django 3.0.
  * Added support for Python 3.8.
  * Moved ``TaggedItemBase.tags_for()`` to ItemBase.
  * Replaced reference to removed Django's ``.virtual_fields`` with
    ``.private_field``.
  * Added ``TextareaTagWidget``.
* Thu Jul  4 2019 Daniel Molkentin <daniel.molkentin@suse.com>
- Update to version 1.1.0
  * Added Finnish translation.
  * Updated Chinese translation.
  * Updated Esperanto translation.
  * Fix form.changed_data to allow early access for a tags defined with blank=True.
- Update to version 1.0.0
  * Backwards incompatible: Remove support for Python 2.
  * Added has_changed() method to taggit.forms.TagField.
  * Added multi-column unique constraint to model TaggedItem on fields
    content_type, object_id, and tag. Databases that contain duplicates will
    need to add a data migration to resolve these duplicates.
  * Fixed TaggableManager.most_common() to always evaluate lazily. Allows
    placing a .most_common() query at the top level of a module.
  * Fixed setting the related_name on a tags manager that exists on a model named Name.
* Fri Mar  1 2019 Daniel Molkentin <daniel.molkentin@suse.com>
- Update to version 0.24
  * The project has moved to Jazzband. This is the first release under the new
    organization. The new repository URL is https://github.com/jazzband/django-taggit.
  * Added support for Django 2.2.
  * Backwards incompatible: Remove support for Django < 1.11
  * Added support for Django 2.1 and Python 3.7
  * Moved TagWidget value conversion from TagWidget.render() to TagWidget.format_value()
  * Added support for Django 2.0
  * Backwards incompatible: Dropped support for EOL Python 3.3
  * Update spanish translation
  * Add testing for Django 1.11 and Python 3.6
  * introduce isort and flake8 in the CI
  * [docs] Fixed links to external apps
  * Improved auto-slug in TagBase to support UUID pk
  * [docs] Added contribution guidelines
  * Backwards incompatible: Drop support for Django 1.7
  * Fix case-insensitive tag creation when setting to a mix of new and existing tags are used
  * Check for case-insensitive duplicates when creating new tags
  * Support __gt__ and __lt__ ordering on Tags
  * Fix list view
  * Update Python version classifiers in setup.py
  * Add Greek translation
  * Document supported versions of Django; fix Travis to test these versions.
  * Fix form tests on Django 1.10
  * Address list_display and fieldsets in admin docs
  * external_apps.txt improvements
  * Remove support for Django 1.4-1.6, again.
  * Add extra_filters argument to the manager’s most_common method
  * Specify app_label for Tag and TaggedItem
  * Fix UnboundLocalError in _TaggableManager.set(..)
  * Update doc links to reflect RTD domain changes
  * Improve Russian translations
  * Add app config, add simplified Chinese translation file
  * Implementation of m2m_changed signal sending
  * Code and tooling improvements
  * Added Spanish and Turkish translations
  * Add the min_count parameter to managers.most_common function
  * Address deprecation warnings
  * Add option to override default tag string parsing
  * Drop support for Python 2.6
  * Silence Django 1.9 warning
  * Django 1.9 compatibility fix
  * Allows custom Through Model with GenericForeignKey
  * Silence Django 1.9 warning about on_delete
  * Django 1.9 beta compatibility
  * Fix unknown column object_id issue with Django 1.6+
  * Database index added on TaggedItem fields content_type & object_id
  * Access default manager via class instead of instance
  * Prevent IntegrityError with custom TagBase classes
  * Fix an admin bug related to the Manager property through_fields
  * Fix bug that assumed all primary keys are named ‘id’
  * Add option to allow case-insensitive tags
  * Fix wrong slugs for non-latin chars
  * Only works if optional GPL dependency (unidecode) is installed
  * Prevent extra JOIN when prefetching
  * Prevent _meta warnings with Django 1.8
  * Django 1.8 support
  * Specify that the internal type of the TaggitManager is a ManyToManyField
  * Fixed 1.7 migrations.
  * Final (hopefully) fixes for the upcoming Django 1.7 release.
  * Added Japanese translation.
  * Backwards incompatible: Support for Django 1.7 migrations. South users have to
    set SOUTH_MIGRATION_MODULES to use taggit.south_migrations for taggit.
  * Backwards incompatible: Django’s new transaction handling is used on Django 1.6 and newer.
  * Backwards incompatible: Tag.save got changed to opportunistically try to save the tag and
    if that fails fall back to selecting existing similar tags and retry – if that fails too
    an IntegrityError is raised by the database, your app will have to handle that.
  * Added Italian and Esperanto translations.
  * Forbid multiple TaggableManagers via generic foreign keys.
  * Fixed support for Django 1.4 and 1.5.
  * Added support for prefetch_related on tags fields.
  * Fixed support for Django 1.7.
  * Made the tagging relations unserializeable again.
  * Allow more than one TaggableManager on models (assuming concrete FKs are used for the relations).
* Sat Sep 28 2013 p.drouand@gmail.com
- Update to version 0.10
  + Support for Django 1.6 and 1.7.
  + Python3 support
  + Dropped support for Django < 1.4.5.
  + Tag names are unique now, use the provided South migrations to upgrade.
- Use download url as source url
- Remove redundant %%clean setion and useless CFLAGS export
- Add documentation from tarball
* Tue Mar 15 2011 alexandre@exatati.com.br
- Update to 0.9.3;
- Spec file regenerated with py2pack;
- Removed m2m_target_field_name-fix.diff, merged in upstream.
* Wed Mar  2 2011 alexandre@exatati.com.br
- Replaced tabs by spaces and removed version in spec file header.
* Tue Mar  1 2011 appleonkel@opensuse.org
- Add patch for https://github.com/alex/django-taggit/issues/60/find
* Mon Jan 17 2011 alexandre@exatati.com.br
- Update t0 0.9.2.
* Sat Sep 25 2010 alexandre@exatati.com.br
- Update to 0.9.1.
* Wed Sep 22 2010 alexandre@exatati.com.br
- Update t 0.9.0;
- Bzip2 source file.
* Tue Jun 22 2010 alexandre@exatati.com.br
- Update to 0.8.0.
* Sat May  8 2010 alexandre@exatati.com.br
- Initial version (0.6.0) for openSUSE.
